<h1>NCapybaraLib</h1>
<p>A small library with a bunch of functions and thingies I made for fun.<br>So far, there's nothing much, but it will grow as time goes.</p>
<p>Check out the library on <a href="https://pypi.org/project/NCapybaraLib/">PyPi</a>!</p>

<h1>Download</h1>
<p>To download this library, run this command:</p>
<blockquote>pip install NCapybaraLib</blockquote>